@@ -47,7 +47,9 @@ extern SEXP
     Matrix_RZXSym,
     Matrix_XtXSym,
     Matrix_ZtXSym,
+    Matrix_ZZxSym,
     Matrix_bVarSym,
+    Matrix_cnamesSym,
     Matrix_devianceSym,
     Matrix_devCompSym,
     Matrix_diagSym,
